local paths = {}

paths.install_prefix = [[/usr/local/share/rspamd]]
paths.install_bin = [[/usr/local/share/rspamd/../../../obj/usr/ports/mail/rspamd/work/rspamd-1.8.3/contrib/lua-torch/torch7]]
paths.install_man = [[/usr/local/share/rspamd/share/man]]
paths.install_lib = [[/usr/local/share/rspamd//usr/local/share/rspamd/lib]]
paths.install_share = [[/usr/local/share/rspamd/share]]
paths.install_include = [[/usr/local/share/rspamd/../../../obj/usr/ports/mail/rspamd/work/rspamd-1.8.3/contrib/lua-torch/torch7]]
paths.install_cmake = [[/usr/local/share/rspamd/share/cmake/torch]]

return paths
